import styled from "styled-components"
import { withStyles } from "@material-ui/core/styles"
import { ExpansionPanel } from "@material-ui/core"
import MuiExpansionSummary from "@material-ui/core/ExpansionPanelSummary"
import MuiExpansionDetails from "@material-ui/core/ExpansionPanelDetails"

import theme from "../../theme"

export const Container = styled.div`
  border-radius: 1rem;
  overflow: hidden;
`

export const ExpansionItem = withStyles({
  root: {
    boxShadow: "none",
    "&:not(:last-child)": {
      borderBottom: 0,
    },
    "&:before": {
      display: "none",
    },
    "&$expanded": {
      margin: "auto",
    },
  },
  expanded: {},
})(ExpansionPanel)

export const ExpansionSummary = withStyles({
  root: {
    position: 'relative',
    backgroundColor: theme.palette.primary.main,
    color: theme.palette.background.main,    
    marginBottom: -1,
    minHeight: 56,
    "&$expanded": {
      minHeight: 56,
    },
    "@media(min-width: 1800px)": {
      padding: `2rem ${theme.spacing(3)}`,
    },
  },
  content: {
    
  },
  expandIcon: {
    color: theme.palette.background.main,
  },
  "::after": {
    content: '',
    position: 'absolute',
    bottom: 0,
    width: '100%',
    height: '5px',
    // background: theme.palette.background.main,
    background: 'red',
  },
  expanded: {},
})(MuiExpansionSummary)

export const ExpansionDetails = withStyles((theme) => ({
  root: {
    padding: theme.spacing(3),
    backgroundColor: theme.palette.background.main,
    border: `2px solid ${theme.palette.primary.main}`,
    "@media(min-width: 1800px)": {
      padding: theme.spacing(3),
    },
  },
}))(MuiExpansionDetails)

export const ExpansionDetailsLast = withStyles((theme) => ({
  root: {    
    padding: theme.spacing(3),
    backgroundColor: theme.palette.background.main,
    borderRadius: "0 0 1rem 1rem",
    border: `2px solid ${theme.palette.primary.main}`,
    "@media(min-width: 1800px)": {
      padding: theme.spacing(3),
    },
  }
}))(MuiExpansionDetails)

export const Divider = styled.div`
  background: ${props => props.theme.palette.background.main};
  width: 96%;
  height: 4px;
  border-radius: 2px;
  position: absolute;
  bottom: 0;
  left: 50%;
  transform: translateX(-50%);
  transition: 150ms ease;

  ${props => props.expanded? `
    opacity: 0;
  `:""}
`
