import styled from 'styled-components'
import { Link } from 'react-router-dom'

export const Button = styled(Link)`
  display: flex;
  align-items: center;
  justify-content: center;
  /* overflow: hidden; */
  background-color: ${props => props.color? props.color : props.theme.palette.button.background};
  color: ${props => props.theme.palette.button.icon};
  width: 45px;
  height: 45px;
  border-radius: 50%;
  border: none;
  transition: all 0.3s cubic-bezier(.25,.8,.25,1);
  margin-left: ${props => props.margin ? "1rem" : "0"};
  transition: 0.2s linear;
  position: relative;
  padding: 0;
  cursor: pointer;

  box-shadow: 4px 10px 28px rgba(0,0,0,0.25), 4px 6px 10px rgba(0,0,0,0.22);
  transition: all 0.3s cubic-bezier(.25,.8,.25,1);

  @media(min-width: 900px) {
    width: 2.5rem;
    height: 2.5rem;
    min-width: 50px;
    min-height: 50px;
  }

  @media(min-width: 900px) and (min-height: 900px) {
    width: 3.5rem;
    height: 3.5rem;
    min-width: 60px;
    min-height: 60px;
  }
  
  &:hover {
    background-color: ${props => props.hover? props.hover : props.theme.palette.button.hover};
    color: ${props => props.theme.palette.button.icon};
    box-shadow: 0 19px 38px rgba(0,0,0,0.30), 0 15px 12px rgba(0,0,0,0.22);
  }

  &:focus {
    outline: none;
  }

  ${props => props.tooltip? `
    &::after {
      --scale: 0;
      content: attr(data-tooltip);
      position: absolute;
      top: 4.5rem;
      padding: .5rem;
      max-width: 8rem;
      text-align: center;      
      background: ${props.theme.palette.secondary.dark};
      color: ${props.theme.palette.background.main};
      border-radius: 5px;
      box-shadow: 0 1px 3px rgba(0,0,0,0.12), 0 1px 2px rgba(0,0,0,0.24);
      transform: scale(var(--scale));
      transition: 150ms transform;
      transform-origin: top center;
      z-index: 2;
    }

    &:hover::after {
      --scale: 1;
    }`
    :
    ""
  }  

  img {
    width: 50%;
  }

  .svg {
    width: 40%;
  }

  .prev {
    transform: translateX(-10%);
  }

  .next {
    transform: translateX(10%);
  }

  ${props => props.disabled? "opacity: 0; pointer-events: none;" : "opacity: 1"};
`

export const ActionButton = styled.button`
  display: flex;
  align-items: center;
  justify-content: center;
  overflow: hidden;
  background-color: ${props => props.color? props.color : props.theme.palette.button.background};
  color: ${props => props.theme.palette.button.icon};
  width: 45px;
  height: 45px;
  border-radius: 50%;
  border: none;
  margin-left: ${props => props.margin ? "1rem" : "0"};
  transition: 0.2s linear;
  padding: 0;
  cursor: pointer;

  box-shadow: 4px 10px 28px rgba(0,0,0,0.25), 4px 6px 10px rgba(0,0,0,0.22);
  transition: all 0.3s cubic-bezier(.25,.8,.25,1);

  @media(min-width: 900px) {
    width: 2.5rem;
    height: 2.5rem;
    min-width: 50px;
    min-height: 50px;
  }

  @media(min-width: 900px) and (min-height: 900px) {
    width: 3.5rem;
    height: 3.5rem;
    min-width: 60px;
    min-height: 60px;
  }
  
  &:hover {
    background-color: ${props => props.hover? props.hover : props.theme.palette.button.hover};
    transition: all 0.3s cubic-bezier(.25,.8,.25,1);
    box-shadow: 0 19px 38px rgba(0,0,0,0.30), 0 15px 12px rgba(0,0,0,0.22);
  }

  &:focus {
    outline: none;
  }

  ${props => props.tooltip? `
    &::after {
      --scale: 0;
      content: attr(data-tooltip);
      position: absolute;
      top: 4.5rem;
      padding: .5rem;
      max-width: 8rem;
      text-align: center;      
      background: ${props.theme.palette.secondary.dark};
      color: ${props.theme.palette.background.main};
      border-radius: 5px;
      box-shadow: 0 1px 3px rgba(0,0,0,0.12), 0 1px 2px rgba(0,0,0,0.24);
      transform: scale(var(--scale));
      transition: 150ms transform;
      transform-origin: top center;
      z-index: 2;
    }

    &:hover::after {
      --scale: 1;
    }`
    :
    ""
  }

  img {
    width: 50%;
  }

  .svg {
    width: 40%;
  }

  .prev {
    transform: translateX(-10%);
  }

  .next {
    transform: translateX(10%);
  }

  ${props => props.disabled? "opacity: 0; pointer-events: none;" : "opacity: 1"};  
  ${props => props.opacity? "opacity: 0.5; pointer-events: none;" : ""};
`