import React, { useState, useRef } from "react"
import { Typography, Box } from "@material-ui/core"

import Header from "../../components/Header"
import Footer from "../../components/Footer"
import Reference from "../../components/Reference"

import { Content, StyledContainer } from "./styles"
import { SelectButton } from '../../theme/commonstyles'

export default function () {
  const headerref = useRef(Header)
  const [selected, setSelected] = useState(0)

  const openRef = (key) => {
    if (!headerref.current) {
      return
    }

    headerref.current.openRef(key)
  }

  const PS = () => {
    return (
      <Typography variant="body1">
        É o principal instrumento de planejamento.
        Consolida as políticas de saúde de uma determinada esfera de governo.
        Assim, há o Plano Municipal de Saúde, o Plano Estadual de Saúde e o
        Plano Nacional de Saúde. <br />
        <br />
        <strong>Composição:</strong>
        <br />
        Conteúdo básico:
        <br />
        • Análise da situação de saúde do município;
        <br />
        • Objetivos, diretrizes, metas e indicadores;
        <br />
        • Monitoramento e avaliação.
        <br />
        <br />
        Validade: 4 anos, do segundo ano do governo vigente ao primeiro ano do
        governo sucessor. Prazo: final de março do primeiro ano de governo.
      </Typography>
    )
  }

  const PAS = () => {
    return (
      <Typography variant="body1">
        Tem como objetivo anualizar e
        operacionalizar as intenções do PS.
        <br />
        <br />
        <strong>Composição:</strong>
        <br />
        Conteúdo básico:
        <br />
        • Objetivos;
        <br />
        • Ações;
        <br />
        • Metas;
        <br />
        • Recursos financeiros atrelados às ações.
        <br />
        <br />
        Validade: anual.
        <br />
        
        Prazo: final de março de cada um dos 4 anos de governo.
      </Typography>
    )
  }

  const RAG = () => {
    return (
      <Typography variant="body1">
        Tem como objetivo a apresentação dos
        resultados alcançados com a implementação da PAS. A aprovação do RAG
        está sujeita a parecer do conselho de saúde da respectiva esfera de
        gestão, demarcando-se aqui uma importante função do controle social no
        processo de planejamento do SUS.
        <br />
        <br />
        <strong>Composição:</strong>
        <br />
        Conteúdo básico:
        <br />
        • Diretrizes, objetivos e indicadores do PMS;
        <br />
        • Metas previstas e executadas da PAS;
        <br />
        • Resultados;
        <br />
        • Análise da Execução Orçamentária.
        <br />
        <br />
        Validade: anual.
        <br />
        Prazo: final de março de cada um dos 4 anos de governo.
      </Typography>
    )
  }

  const RDQA = () => {
    return (
      <Typography variant="body1">
        Tem como objetivo o
        monitoramento da implementação das ações da PAS. Trata-se de apuração
        trimestral do RAG, e será composto pelas informações cumulativas dos
        três RDQA anteriores.
        <br />
        <br />
        <strong>Composição:</strong>
        <br />
        Conteúdo básico:
        <br />
        • Diretrizes, objetivos e indicadores do PMS;
        <br />
        • Metas previstas e executadas da PAS;
        <br />
        • Resultados;
        <br />
        • Análise da Execução Orçamentária.
        <br />
        <br />
        Validade: anual.
        <br />
        Prazo: final de março de cada um dos 4 anos de governo.
      </Typography>
    )
  }

  const texts = [<PS />, <PAS />, <RAG />, <RDQA />]

  return (
    <StyledContainer>
      <Header ref={headerref} />
      <Box className="container">
        <Content>
          <Box className="title">
            <Typography variant="h3">
              Instrumentos de planejamento do SUS
            </Typography>
          </Box>
          <Box className="wrapper">
            <Box className="text">
              <Typography variant="body1" className="indented">
                O planejamento no SUS é uma atividade obrigatória e de competência
                das três esferas de gestão. A transferência de recursos
                financeiros entre os entes federados está condicionada ao
                cumprimento do processo de planejamento.
                <Reference num={3} onClick={() => openRef(3)} />
                <br/><br/>
              </Typography>
              <Typography variant="body1" className="indented">
                <strong>Clique</strong> nos botões abaixo para conhecer quatro instrumentos de planejamento<Reference num={4} onClick={() => openRef(4)} />:
              </Typography>
            </Box>
            <Box className="bottom">
              <Box className="buttons">
                {/* "amount" aqui é a quantidade de botões para se dividir a altura */}
                <SelectButton
                  amount={4}
                  onClick={() => setSelected(0)}
                  selected={selected === 0 ? true : false}
                >
                  <Typography variant="body2">Plano de Saúde (PS)</Typography>
                </SelectButton>
                <SelectButton
                  amount={4}
                  onClick={() => setSelected(1)}
                  selected={selected === 1 ? true : false}
                >
                  <Typography variant="body2">
                  Programação Anual de Saúde (PAS)
                  </Typography>
                </SelectButton>
                <SelectButton
                  amount={4}
                  onClick={() => setSelected(2)}
                  selected={selected === 2 ? true : false}
                >
                  <Typography variant="body2">
                    Relatório Anual de Gestão (RAG)
                  </Typography>
                </SelectButton>
                <SelectButton
                  amount={4}
                  onClick={() => setSelected(3)}
                  selected={selected === 3 ? true : false}
                  last
                >
                  <Typography variant="body2">
                    Relatório Detalhado do Quadrimestre Anterior (RDQA)
                  </Typography>
                </SelectButton>
              </Box>
              <Box className="content">
                <Typography variant="body1">{texts[selected]}</Typography>
              </Box>
            </Box>
          </Box>
        </Content>
      </Box>
      <Footer prev="/p6" next="/p8" />
    </StyledContainer>
  )
}
