import styled from 'styled-components'
import { Box } from '@material-ui/core'

import { containerstyles, animationstyles, fontstyles, contentstyles } from '../../theme/commonstyles'

export const StyledContainer = styled(Box)`
  ${containerstyles};
  ${animationstyles};
  ${fontstyles};
`

export const Content = styled(Box)`
  flex-grow: 1;
  display: flex;
  flex-direction: column;
  justify-content: center;
  padding: 1rem;

  ${contentstyles};

  .text {    
    display: flex;
    flex-direction: column;
    justify-content: center;
    margin-bottom: 1rem;

    @media(min-width: 900px) {
      margin: .75rem 0;
    }

    @media(min-width: 1800px) {
      margin: 2.5rem 0;
    }
  }

  .fluxogram {
    flex-grow: 1;
    display: flex;
    position: relative;

    img.background {      
      position: absolute;      
      width: 100%;

      @media(min-width: 900px) {
        max-width: 795px;
        display: none;
      }

      @media(min-width: 1800px) {
        max-width: 1116px;
      }
    }
  }

  .fluxogram .placement {
    flex-grow: 1;
    display: flex;
    align-items: center;
    justify-content: center;    
    position: relative;    
  }

  .ppa, .ldo, .loa, .pms, .pas, .rag, .rdqa, .txtesquerda, .txtdireita, .txtbaixo, .txtrdqa, .greendotbox, .arrow-1, .arrow-2, .arrow-3, .arrow-4, .arrow-5, .arrow-6, .arrow-7, .arrow-8 {
    position: absolute;
    z-index: 1;
    display: flex;
    flex-direction: column;       
  }

  .greenbox {
    position: absolute;
    z-index: 0;
  }

  .ppa p, .ldo p, .loa p, .pms p, .pas p, .rag p, .rdqa p {
    margin-top: .25rem;
    margin-left: .5rem;
    font-weight: bolder;
  }

  .ppa {
    right: 5.5%;
    top: calc(calc(27vw - 3.5rem) * 1.73);

    @media(min-width: 900px) {      
      top: 0%;      
      left: 20%;  
    }    

    @media(min-width: 900px) and (min-height: 900px) {
      top: 5%;
    }
  }

  .ldo {
    right: 5.5%;
    top: calc(calc(45vw - 3.5rem) * 1.73);

    @media(min-width: 900px) {
      top: 0%;
      left: 40%;
    }

    @media(min-width: 900px) and (min-height: 900px) {
      top: 5%;
    }
  }

  .loa {
    right: 5.5%;
    top: calc(calc(64vw - 3.5rem) * 1.73);

    @media(min-width: 900px) {
      top: 0%;
      left: 60%;
    }

    @media(min-width: 900px) and (min-height: 900px) {
      top: 5%;
    }
  }

  .pms {
    left: 50%;
    top: calc(calc(27vw - 3.5rem) * 1.73);

    @media(min-width: 900px) {
      top: 41%;
      left: 20%;
    }

    @media(min-width: 900px) and (min-height: 900px) {
      top: 40%;
    }
  }

  .pas {
    left: 50%;
    top: calc(calc(64vw - 3.5rem) * 1.73);

    @media(min-width: 900px) {
      top: 41%;
      left: 60%;
    }

    @media(min-width: 900px) and (min-height: 900px) {
      top: 40%;
    }
  }

  .rag {
    left: 50%;
    top: calc(calc(81vw - 3.5rem) * 1.73);

    @media(min-width: 900px) {
      top: 41%;
      left: 75%;  
    }

    @media(min-width: 900px) and (min-height: 900px) {
      top: 40%;
    }
  }

  .rdqa {
    top: calc(calc(60vw - 3.5rem) * 1.73);
    left: calc(22vw - 3.5rem);

    @media(min-width: 900px) {
      top: 74.5%;
      left: 40%;  
    }

    @media(min-width: 900px) and (min-height: 900px) {
      top: 76.5%;
    }
  }

  .texto {
    display: none;

    @media(min-width: 900px) {
      width: 10rem;
      display: flex;
      justify-content: center;

      p {
        text-align: center;
        font-weight: bolder;
      } 
    }    
  }

  .txtesquerda {
    top: 46%;
    left: 1%;

    @media(min-width: 900px) and (min-height: 900px) {
      left: 3%;
      top: 45%;
    }
  }

  .txtdireita {
    top: 46%;
    left: 85%; 

    @media(min-width: 900px) and (min-height: 900px) {
      top: 43%;
    }
  }

  .txtbaixo {
    top: 83%;
    left: 20%;
    transform: translateX(-30%);

    @media(min-width: 900px) and (min-height: 900px) {
      top: 77%;
    }
  }

  .txtrdqa {
    top: 77%;
    left: 65%;
  }  

  .greenbox {
    @media(max-width: 899px) {
      display: none;
    }

    @media(min-width: 900px) {
      width: 82.5%;
      left: 0%;
      top: 37.5%;
      height: 31%;
      border: 2px solid ${props => props.theme.palette.primary.main};
      border-radius: 1rem;  
    }    

    @media(min-width: 900px) and (min-height: 900px) {
      height: 20%;
    }

    @media(min-width: 1800px) {
      height: 25%;
    }
    
    ::after {
      content: '→';
      font-size: 1.75rem;
      font-weight: 900;
      color: ${props => props.theme.palette.primary.main};
      position: absolute;
      right: -1.75rem;
      top: 50%;
      transform: translateY(-50%);

      @media(min-width: 1800px) {
        font-size: 3rem;
        right: -3rem;
      }
    }
  }

  .greendotbox {    
    @media(max-width: 899px) {
      display: none;
    }

    border-top: none;
    border-left: none;
    border-right: 2px dashed ${props => props.theme.palette.primary.main};
    border-bottom: 2px dashed ${props => props.theme.palette.primary.main};

    width: 17%;
    height: 22.5%;    
    top: 68%;
    left: 45%;

    @media(min-width: 900px) and (min-height: 900px){
      top: 57.5%;  
    }

    @media(min-width: 1800px) {
      height: 21.5%;
      top: 63%;
    }
  }

  .arrow {
    @media(max-width: 899px) {
      display: none;
    }

    p {
      font-size: 2rem;
      color: ${props => props.theme.palette.primary.main};

      @media(min-width: 900px) and (min-height: 900px) {
        font-size: 4rem;
      }
    }
  }

  .arrow-1 {
    top: 5%;    
    left: 29.5%;
    transform: translateY(-5%);    
  }

  .arrow-2 {
    top: 5%;    
    left: 49.5%;
    transform: translateY(-5%);
  }

  .arrow-3 {
    top: 46%;    
    left: 39.5%;
    transform: translateY(-5%);

    @media(min-width: 900px) and (min-height: 900px) {
      top: 43%;
    }
  }

  .arrow-4 {
    top: 46%;
    left: 67%;
    transform: translateY(-5%);

    @media(min-width: 900px) and (min-height: 900px) {
      top: 43%;
    }
  }

  .arrow-5 {
    top: 24%;
    left: 21.2%;
    
    @media(min-width: 900px) and (min-height: 900px) {
      top: 20.5%;
      left: 20.5%;
    }

    @media(min-width: 1800px) {
      top: 22.5%;
      left: 20.75%;
    }
  }

  .arrow-6 {
    top: 24%;
    left: 61.2%;

    @media(min-width: 900px) and (min-height: 900px) {
      top: 20.5%;
      left: 60.5%;
    }

    @media(min-width: 1800px) {
      top: 22.5%;
      left: 60.75%;
    }
  }

  .arrow-7 {
    top: 67%;
    left: 21.2%;

    @media(min-width: 900px) and (min-height: 900px) {      
      top: 60%;    
      left: 20.5%;
    }

    @media(min-width: 1800px) {
      top: 60.5%;
      left: 20.75%;
    }
  }

  .indented {
    text-indent: 2rem;
  }
`